Class: Rooibos::Message::Bubbled

Inherits:
Data
  • Object
show all
Includes:
Predicates
Defined in:
lib/rooibos/message/bubbled.rb

Overview

Message synthesized by Router when a child fragment bubbles.

When a child fragment returns Command.bubble(message), the Router wraps the inner message in Bubbled and dispatches it through the outward flow (observe, then intercept).

message

The inner message that was bubbled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Predicates

#==, #method_missing, #respond_to_missing?, #to_sym

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Rooibos::Message::Predicates

Instance Attribute Details

#messageObject (readonly)

Returns the value of attribute message

Returns:

  • (Object)

    the current value of message



17
18
19
# File 'lib/rooibos/message/bubbled.rb', line 17

def message
  @message
end

Instance Method Details

#bubbled?Boolean

Returns:

  • (Boolean)


24
25
26
# File 'lib/rooibos/message/bubbled.rb', line 24

def bubbled?
  true
end

#deconstruct_keys(_keys) ⇒ Object



20
21
22
# File 'lib/rooibos/message/bubbled.rb', line 20

def deconstruct_keys(_keys)
  { type: :bubbled, message: }
end