Class: Rooibos::Message::Bubbled
- Inherits:
-
Data
- Object
- Data
- Rooibos::Message::Bubbled
- Includes:
- Predicates
- Defined in:
- lib/rooibos/message/bubbled.rb
Overview
Message synthesized by Router when a child fragment bubbles.
When a child fragment returns Command.bubble(message), the Router wraps the inner message in Bubbled and dispatches it through the outward flow (observe, then intercept).
- message
-
The inner message that was bubbled.
Instance Attribute Summary collapse
-
#message ⇒ Object
readonly
Returns the value of attribute message.
Instance Method Summary collapse
Methods included from Predicates
#==, #method_missing, #respond_to_missing?, #to_sym
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Rooibos::Message::Predicates
Instance Attribute Details
#message ⇒ Object (readonly)
Returns the value of attribute message
17 18 19 |
# File 'lib/rooibos/message/bubbled.rb', line 17 def @message end |
Instance Method Details
#bubbled? ⇒ Boolean
24 25 26 |
# File 'lib/rooibos/message/bubbled.rb', line 24 def bubbled? true end |
#deconstruct_keys(_keys) ⇒ Object
20 21 22 |
# File 'lib/rooibos/message/bubbled.rb', line 20 def deconstruct_keys(_keys) { type: :bubbled, message: } end |